@@ -91,16 +91,18 @@ class RIMDB():
         ret = pd.read_sql(query.statement, self.engine)
         return ret
 
-    def grabar_modelo(self, modelo, llave) -> bool:
+    def grabar_modelo(self, modelo) -> bool:
         try:
             clase = modelo.__class__
-            query = self.session.query(clase).filter(clase[llave] == modelo[llave])
+            query = self.session.query(clase).filter(clase.llave == modelo.llave)
             if query.first() is None:
                 self.session.add(modelo)
+                print('add', modelo.__tablename__)
             else:
                 upd = modelo.__dict__
                 del upd['_sa_instance_state']
                 query.update(upd)
+                print('update', modelo.__tablename__)
             self.session.commit()
             return True
         except IntegrityError as e:
